getProgressWeights property

List<double> get getProgressWeights

Returns a list of progress weights calculated from each child's current percentage, influenced by the associated flex factor.

Implementation

List<double> get getProgressWeights => _progressWeights;